@@ -11,7 +11,9 @@ class Checkbox(ValuedNode):
     def __init__(self, **kwargs):
         '''kwarg value is True if the checkbox is initially checked'''
         def click_event(_):
-            return self.activate()
+            if self.is_clicked():
+                return self.activate()
+            return False
         kwargs['value'] = kwargs.get('value', False)
         ValuedNode.__init__(self, **kwargs)
         self.add_processor(Event.ON_CLICKUP, click_event)
