@@ -56,6 +56,11 @@ BUTTON_STYLE = {
         'color': Colors.GREEN_YELLOW
     }
 }
+LBL_LNK_STYLE = {
+    'overed': {
+        'color': Colors.BLUE_STEEL
+    }
+}
 
 
 def monster_table(m):
@@ -145,12 +150,13 @@ def controls_window(win_sys, title):
                 colspan={0: 2})
     for ip in ips:
         tbl.new_row({0: ip}, colspan={0: 2})
-    tbl.new_row({0: cb, 1: Label('a checkbox', label_for=cb)})
+    tbl.new_row({0: cb, 1: Label('a checkbox', label_for=cb, cls='lbl_lnk')})
     tbl.new_row({0: Label('how are you?')},
                 colspan={0: 2})
     for how in ['fine', 'ok', 'not great']:
         how_cb = Radiobox(grp, how)
-        tbl.new_row({0: how_cb, 1: Label(how, label_for=how_cb)})
+        tbl.new_row({0: how_cb, 1:
+                     Label(how, label_for=how_cb, cls='lbl_lnk')})
     tbl.new_row({0: Label('select a fruit (mousewheel can be used)')},
                 colspan={0: 2})
     tbl.new_row({0: fruits},
@@ -242,8 +248,6 @@ def cursor_window(win_sys, title):
     Cursor.set_default(cursor_base_img, ctx=Context.BASE)
     Cursor.activate()
 
-    #StyleClass.get(Link).set_attr('overed', 'cursor', cursor_overed_img)
-
     elf = Image(Media.get_image(os.path.join(MEDIA_DIR, 'elf.png')))
     elf.set_style('cursor', cursor_overed_img, ctx='overed')
     elf.set_style('cursor', cursor_clicked_img, ctx='clicked')
@@ -754,6 +758,7 @@ def go():
     pg.display.set_caption('pygwin v{} - test application'.format(VERSION))
     DefaultStyle.set_default()
     StyleClass.new('button', BUTTON_STYLE)
+    StyleClass.new('lbl_lnk', LBL_LNK_STYLE)
     win_sys = WindowSystem(screen)
     p = top_panel()
     p.open(pos=(0, 0))
